@@ -19,19 +19,19 @@ def build_config() -> dict[str, str]:
         python_path=r"/usr/pkg/bin/python3.13",
 
         # Package versions
-        contourpy_version="1.3.2",
-        meson_version="1.8.2",
+        contourpy_version="1.3.3",
+        meson_version="1.9.0",
         mesonpy_version="0.18.0",
-        pybind11_version="2.13.6",
+        pybind11_version="3.0.1",
 
         # Misc meson settings
         meson_backend="ninja",
-        build_dir=r"/pbulk/work/graphics/py-contourpy/work/contourpy-1.3.2/.mesonpy-pukmpz8c/lib/contourpy/util",
-        source_dir=r"/pbulk/work/graphics/py-contourpy/work/contourpy-1.3.2/lib/contourpy/util",
+        build_dir=r"/tmp/pkgbuild/graphics/py-contourpy/work/contourpy-1.3.3/.mesonpy-tnbbg09m/lib/contourpy/util",
+        source_dir=r"/tmp/pkgbuild/graphics/py-contourpy/work/contourpy-1.3.3/lib/contourpy/util",
         cross_build="False",
 
         # Build options
-        build_options=r"-Dbuildtype=release -Db_ndebug=if-release -Db_vscrt=md -Dvsenv=True --native-file=/pbulk/work/graphics/py-contourpy/work/contourpy-1.3.2/.mesonpy-pukmpz8c/meson-python-native-file.ini",
+        build_options=r"-Dbuildtype=release -Db_ndebug=if-release -Db_vscrt=md -Dvsenv=True --native-file=/tmp/pkgbuild/graphics/py-contourpy/work/contourpy-1.3.3/.mesonpy-tnbbg09m/meson-python-native-file.ini",
         buildtype="release",
         cpp_std="c++17",
         debug="False",
@@ -42,19 +42,19 @@ def build_config() -> dict[str, str]:
 
         # C++ compiler
         compiler_name="gcc",
-        compiler_version="7.5.0",
+        compiler_version="10.5.0",
         linker_id="ld.bfd",
         compile_command="c++",
 
         # Host machine
-        host_cpu="arm",
-        host_cpu_family="arm",
-        host_cpu_endian="little",
+        host_cpu="powerpc",
+        host_cpu_family="ppc",
+        host_cpu_endian="big",
         host_cpu_system="netbsd",
 
         # Build machine, same as host machine if not a cross_build
-        build_cpu="arm",
-        build_cpu_family="arm",
-        build_cpu_endian="little",
+        build_cpu="powerpc",
+        build_cpu_family="ppc",
+        build_cpu_endian="big",
         build_cpu_system="netbsd",
     )
